pub struct LayoutResult {
pub layout: LayoutNode,
pub info: InfoNode,
pub version: u64,
}Expand description
The layout the builder finished on the background thread.
Fields
layout: LayoutNodeinfo: InfoNodeversion: u64Sequence number of the task that produced this result.